# If the trigger file doesn't exist, create it and start the accelemymote daemon. If it does exist, remove it (killing the daemon) and don't start.
if [ ! -f /tmp/accelemymote-live ]
then
touch /tmp/accelemymote-live
/opt/maemo/usr/bin/accelemymote
fi
rm /tmp/accelemymote-live

